import React, { useCallback, useEffect, useState, useMemo } from 'react';
import { Menu } from 'antd';
import type { ItemType } from 'antd/es/menu/hooks/useItems';
import { Link, useMatches } from 'react-router-dom';
import { useGlobalStore } from '@/store/global';
import { antdIcons } from '@/assets/antd-icons';
import { Menu as MenuType } from '@/models';
import { useMenusStore }  from '@/store/global/menu';

const SlideMenu = () => {

  const matches = useMatches();

  const [openKeys, setOpenKeys] = useState<string[]>([]);
  const [selectKeys, setSelectKeys] = useState<string[]>([]);

  const { collapsed, } = useGlobalStore();

  useEffect(() => {
    if (collapsed) {
      setOpenKeys([]);
    } else {
      const [match] = matches || [];
      if (match) {
        // 获取当前匹配的路由，默认为最后一个
        const route = matches.at(-1);
        // 从匹配的路由中取出自定义参数
        const handle = route?.handle as any;
        // 从自定义参数中取出上级path，让菜单自动展开
        setOpenKeys(handle?.parentPaths || []);
        // 让当前菜单和所有上级菜单高亮显示
        setSelectKeys([...(handle?.parentPaths || []), handle?.path] || []);
      }
    }
  }, [
    matches,
    collapsed,
  ]);

  const getMenuTitle = (menu: MenuType) => {
    if (menu?.children?.filter(menu => menu.visible)?.length) {
      return menu.name;
    }
    return (
      <Link to={menu.path}>{menu.name}</Link>
    );
  }

  const treeMenuData = useCallback((menus: MenuType[]): ItemType[] => {
    return (menus).map((menu: MenuType) => {
        const children = menu?.children?.filter(menu => menu.visible) || [];
        const type = ''//(children.length > 0 && (menu.parentPaths?.length??0 > 0)) ? 'group': ''
        return {
          type: type,
          key: menu.path,
          label: getMenuTitle(menu),
          icon: menu.icon && antdIcons[menu.icon] && React.createElement(antdIcons[menu.icon]),
          children: children.length ? treeMenuData(children || []) : null,
        };
      })
  }, []);


  const { menus } = useMenusStore();
  const menuData = useMemo(() => {
    return treeMenuData(menus?.filter(menu => menu.visible) || []);
  }, [menus]);

  return (
    <Menu
      className='bg-primary color-transition'
      mode="inline"
      selectedKeys={selectKeys}
      style={{ height: '100%', borderRight: 0 }}
      items={menuData}
      inlineCollapsed={collapsed}
      openKeys={openKeys}
      onOpenChange={setOpenKeys}
    />
  )
}

export default SlideMenu;
